@@ -19,7 +19,7 @@ def check_and_install():
     if pkg.is_installed:
         print("{pkg_name} already installed".format(pkg_name=pkg_name))
     else:
-        print("installing {pkg_name}".format(pkg_name=pkg_name))
+        print("installing {pkg_name}...".format(pkg_name=pkg_name))
         pkg.mark_install()
         try:
             cache.commit()
@@ -28,6 +28,7 @@ def check_and_install():
                 "package installation failed [{err}]".format(err=str(err)),
                 file=sys.stderr,
             )
+        print("done")
 
 
 def mount(path_name, credentials):
@@ -51,7 +52,7 @@ def mount(path_name, credentials):
                 credentials["bucket"],
                 path_name,
                 "-o",
-                "url=https://s3.us.cloud-object-storage.appdomain.cloud",
+                "url=" + credentials["endpoint_url"],
             ],
             stdout=subprocess.PIPE,
             stderr=subprocess.PIPE,
@@ -60,3 +61,8 @@ def mount(path_name, credentials):
 
         if err:
             print(err)
+        else:
+            print(credentials["bucket"] + " mounted")
+
+    else:
+        print(credentials["bucket"] + " mounted")
